def get_credentials():
    # You can use encryption or encoding here
    # This is a simple example - you might want to make this more secure
    credentials = {
        "url": "https://mveuypcpvdavhyrtmreh.supabase.co",
        "key": "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJzdXBhYmFzZSIsInJlZiI6Im12ZXV5cGNwdmRhdmh5cnRtcmVoIiwicm9sZSI6ImFub24iLCJpYXQiOjE3MzU3NDU0MjAsImV4cCI6MjA1MTMyMTQyMH0.PYLV0htWM2N5YDcxzHLXZqtrV7z-Yq76G7EfKaAjhkY"
    }
    return credentials 